==> rustc_1.87.0+dfsg1.orig.tar.xz: rustc-1.87.0-src/src/tools/rustc-perf/collector/compile-benchmarks/stm32f4-0.14.0/src/stm32f429/dma2d/fgcolr.rs <==
#[doc = "Register `FGCOLR` reader"]
pub struct R(crate::R<FGCOLR_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<FGCOLR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<FGCOLR_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<FGCOLR_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `FGCOLR` writer"]
pub struct W(crate::W<FGCOLR_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<FGCOLR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<FGCOLR_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<FGCOLR_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `RED` reader - Red Value"]
pub struct RED_R(crate::FieldReader<u8, u8>);
impl RED_R {
    pub(crate) fn new(bits: u8) -> Self {
        RED_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for RED_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `RED` writer - Red Value"]
pub struct RED_W<'a> {
    w: &'a mut W,
}
impl<'a> RED_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0xff << 16)) | ((value as u32 & 0xff) << 16);
        self.w
    }
}
#[doc = "Field `GREEN` reader - Green Value"]
pub struct GREEN_R(crate::FieldReader<u8, u8>);
impl GREEN_R {
    pub(crate) fn new(bits: u8) -> Self {
        GREEN_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for GREEN_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `GREEN` writer - Green Value"]
pub struct GREEN_W<'a> {
    w: &'a mut W,
}
impl<'a> GREEN_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0xff << 8)) | ((value as u32 & 0xff) << 8);
        self.w
    }
}
#[doc = "Field `BLUE` reader - Blue Value"]
pub struct BLUE_R(crate::FieldReader<u8, u8>);
impl BLUE_R {
    pub(crate) fn new(bits: u8) -> Self {
        BLUE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for BLUE_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `BLUE` writer - Blue Value"]
pub struct BLUE_W<'a> {
    w: &'a mut W,
}
impl<'a> BLUE_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xff) | (value as u32 & 0xff);
        self.w
    }
}
impl R {
    #[doc = "Bits 16:23 - Red Value"]
    #[inline(always)]
    pub fn red(&self) -> RED_R {
        RED_R::new(((self.bits >> 16) & 0xff) as u8)
    }
    #[doc = "Bits 8:15 - Green Value"]
    #[inline(always)]
    pub fn green(&self) -> GREEN_R {
        GREEN_R::new(((self.bits >> 8) & 0xff) as u8)
    }
    #[doc = "Bits 0:7 - Blue Value"]
    #[inline(always)]
    pub fn blue(&self) -> BLUE_R {
        BLUE_R::new((self.bits & 0xff) as u8)
    }
}
impl W {
    #[doc = "Bits 16:23 - Red Value"]
    #[inline(always)]
    pub fn red(&mut self) -> RED_W {
        RED_W { w: self }
    }
    #[doc = "Bits 8:15 - Green Value"]
    #[inline(always)]
    pub fn green(&mut self) -> GREEN_W {
        GREEN_W { w: self }
    }
    #[doc = "Bits 0:7 - Blue Value"]
    #[inline(always)]
    pub fn blue(&mut self) -> BLUE_W {
        BLUE_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "foreground color register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [fgcolr](index.html) module"]
pub struct FGCOLR_SPEC;
impl crate::RegisterSpec for FGCOLR_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [fgcolr::R](R) reader structure"]
impl crate::Readable for FGCOLR_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [fgcolr::W](W) writer structure"]
impl crate::Writable for FGCOLR_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets FGCOLR to value 0"]
impl crate::Resettable for FGCOLR_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> rustc_1.89.0+dfsg1.orig.tar.xz: rustc-1.89.0-src/src/tools/rustc-perf/collector/compile-benchmarks/stm32f4-0.15.1/src/stm32f429/dma2d/fgcolr.rs <==
#[doc = "Register `FGCOLR` reader"]
pub struct R(crate::R<FGCOLR_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<FGCOLR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<FGCOLR_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<FGCOLR_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `FGCOLR` writer"]
pub struct W(crate::W<FGCOLR_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<FGCOLR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<FGCOLR_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<FGCOLR_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `RED` reader - Red Value"]
pub type RED_R = crate::FieldReader<u8, u8>;
#[doc = "Field `RED` writer - Red Value"]
pub type RED_W<'a, const O: u8> = crate::FieldWriter<'a, u32, FGCOLR_SPEC, u8, u8, 8, O>;
#[doc = "Field `GREEN` reader - Green Value"]
pub type GREEN_R = crate::FieldReader<u8, u8>;
#[doc = "Field `GREEN` writer - Green Value"]
pub type GREEN_W<'a, const O: u8> = crate::FieldWriter<'a, u32, FGCOLR_SPEC, u8, u8, 8, O>;
#[doc = "Field `BLUE` reader - Blue Value"]
pub type BLUE_R = crate::FieldReader<u8, u8>;
#[doc = "Field `BLUE` writer - Blue Value"]
pub type BLUE_W<'a, const O: u8> = crate::FieldWriter<'a, u32, FGCOLR_SPEC, u8, u8, 8, O>;
impl R {
    #[doc = "Bits 16:23 - Red Value"]
    #[inline(always)]
    pub fn red(&self) -> RED_R {
        RED_R::new(((self.bits >> 16) & 0xff) as u8)
    }
    #[doc = "Bits 8:15 - Green Value"]
    #[inline(always)]
    pub fn green(&self) -> GREEN_R {
        GREEN_R::new(((self.bits >> 8) & 0xff) as u8)
    }
    #[doc = "Bits 0:7 - Blue Value"]
    #[inline(always)]
    pub fn blue(&self) -> BLUE_R {
        BLUE_R::new((self.bits & 0xff) as u8)
    }
}
impl W {
    #[doc = "Bits 16:23 - Red Value"]
    #[inline(always)]
    pub fn red(&mut self) -> RED_W<16> {
        RED_W::new(self)
    }
    #[doc = "Bits 8:15 - Green Value"]
    #[inline(always)]
    pub fn green(&mut self) -> GREEN_W<8> {
        GREEN_W::new(self)
    }
    #[doc = "Bits 0:7 - Blue Value"]
    #[inline(always)]
    pub fn blue(&mut self) -> BLUE_W<0> {
        BLUE_W::new(self)
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "foreground color register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [fgcolr](index.html) module"]
pub struct FGCOLR_SPEC;
impl crate::RegisterSpec for FGCOLR_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [fgcolr::R](R) reader structure"]
impl crate::Readable for FGCOLR_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [fgcolr::W](W) writer structure"]
impl crate::Writable for FGCOLR_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets FGCOLR to value 0"]
impl crate::Resettable for FGCOLR_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
